..
    : TAMkin is a post-processing toolkit for normal mode analysis, thermochemistry
    : and reaction kinetics.
    : Copyright (C) 2008-2012 Toon Verstraelen <Toon.Verstraelen@UGent.be>, An Ghysels
    : <An.Ghysels@UGent.be> and Matthias Vandichel <Matthias.Vandichel@UGent.be>
    : Center for Molecular Modeling (CMM), Ghent University, Ghent, Belgium; all
    : rights reserved unless otherwise stated.
    :
    : This file is part of TAMkin.
    :
    : TAMkin is free software; you can redistribute it and/or
    : modify it under the terms of the GNU General Public License
    : as published by the Free Software Foundation; either version 3
    : of the License, or (at your option) any later version.
    :
    : In addition to the regulations of the GNU General Public License,
    : publications and communications based in parts on this program or on
    : parts of this program are required to cite the following article:
    :
    : "TAMkin: A Versatile Package for Vibrational Analysis and Chemical Kinetics",
    : An Ghysels, Toon Verstraelen, Karen Hemelsoet, Michel Waroquier and Veronique
    : Van Speybroeck, Journal of Chemical Information and Modeling, 2010, 50,
    : 1736-1750W
    : http://dx.doi.org/10.1021/ci100099g
    :
    : TAMkin is distributed in the hope that it will be useful,
    : but WITHOUT ANY WARRANTY; without even the implied warranty of
    : MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    : GNU General Public License for more details.
    :
    : You should have received a copy of the GNU General Public License
    : along with this program; if not, see <http://www.gnu.org/licenses/>
    :
    : --

How to cite TAMkin
##################


If you use TAMkin for your research or for the preparation of publications,
please cite the following paper: Ghysels, A.; Verstraelen, T.; Hemelsoet, K.;
Waroquier, M.; Van Speybroeck, V. *J. Chem. Inf. Model.* **2010**, 50,
1736-1750.
(`http://dx.doi.org/10.1021/ci100099g <http://dx.doi.org/10.1021/ci100099g>`_).

For Bibtex users::

    @article{TAMkin,
        author = {Ghysels, An and Verstraelen, Toon and Hemelsoet, Karen and Waroquier, Michel and Van Speybroeck, Veronique},
        day = {26},
        doi = {10.1021/ci100099g},
        journal = {J. Chem. Inf. Model.},
        month = aug,
        number = {9},
        pages = {1736--1750},
        title = {{TAMkin}: A Versatile Package for Vibrational Analysis and Chemical Kinetics},
        url = {http://dx.doi.org/10.1021/ci100099g},
        volume = {50},
        year = {2010}
    }


For Endnote users (RIS format)::

    TY  - JOUR
    TI  - TAMkin: A Versatile Package for Vibrational Analysis and Chemical Kinetics
    JF  - J. Chem. Inf. Model.
    VL  - 50
    IS  - 9
    SP  - 1736
    EP  - 1750
    PB  - American Chemical Society
    AU  - Ghysels, An
    AU  - Verstraelen, Toon
    AU  - Hemelsoet, Karen
    AU  - Waroquier, Michel
    AU  - Van Speybroeck, Veronique
    PY  - 2010/08/26/
    UR  - http://dx.doi.org/10.1021/ci100099g


In addition the the above paper, several other papers were published about the
new normal mode analysis methods in TAMkin. If any of these methods are used,
please cite the approriate papers:

* "Vibrational Modes in partially optimized molecular systems.", An Ghysels,
  Dimitri Van Neck, Veronique Van Speybroeck, Toon Verstraelen and Michel
  Waroquier, *J. Chem. Phys.*, Vol. 126 (22): Art. No. 224102, **2007**
  `10.1063/1.2737444 <http://dx.doi.org/10.1063/1.2737444>`_

* "Cartesian formulation of the Mobile Block Hesian Approach to vibrational
  analysis in partially optimized systems", An Ghysels, Dimitri Van Neck and
  Michel Waroquier, *J. Chem. Phys.*, Vol. 127 (16), Art. No. 164108,
  **2007** `10.1063/1.2789429 <http://dx.doi.org/10.1063/1.2789429>`_

* "Calculating reaction rates with partial Hessians: validation of the MBH
  approach", An Ghysels, Veronique Van Speybroeck, Toon Verstraelen, Dimitri Van
  Neck and Michel Waroquier, *J. Chem. Theory Comput.*, Vol. 4
  (4), 614-625, **2008** `10.1021/ct7002836 <http://dx.doi.org/10.1021/ct7002836>`_

* "Mobile Block Hessian approach with linked blocks: an efficient approach for
  the calculation of frequencies in macromolecules", An Ghysels, Veronique Van
  Speybroeck, Ewald Pauwels, Dimitri Van Neck, Bernard R. Brooks and Michel
  Waroquier, *J. Chem. Theory Comput.*, Vol. 5 (5), 1203-1215,
  **2009** `10.1021/ct800489r <http://dx.doi.org/10.1021/ct800489r>`_

* "Normal modes for large molecules with arbitrary link constraints in the
  mobile block Hessian approach", An Ghysels, Dimitri Van Neck, Bernard R.
  Brooks, Veronique Van Speybroeck and Michel Waroquier, *J. Chem.
  Phys.*, Vol. 130 (18), Art. No. 084107, **2009** `10.1063/1.3071261
  <http://dx.doi.org/10.1063/1.3071261>`_
